@@ -1,8 +1,6 @@
-from selenium.webdriver.support import expected_conditions as ec
-from selenium.webdriver.support.ui import WebDriverWait
 from selenium_recaptcha_solver import RecaptchaSolver, StandardDelayConfig
-from selenium_stealth import stealth
-from selenium import webdriver
+from selenium.webdriver.common.by import By
+import undetected_chromedriver as webdriver
 import pytest
 
 
@@ -19,21 +17,8 @@ options.add_argument('--incognito')
 options.add_argument('--no-sandbox')
 options.add_argument("--disable-extensions")
 
-
 test_driver = webdriver.Chrome(options=options)
 
-
-stealth(
-    test_driver,
-    languages=["en-US", "en"],
-    vendor="Google Inc.",
-    platform="Win32",
-    webgl_vendor="Intel Inc.",
-    renderer="Intel Iris OpenGL Engine",
-    fix_hairline=True,
-)
-
-
 solver = RecaptchaSolver(driver=test_driver, delay_config=StandardDelayConfig())
 
 
@@ -41,11 +26,7 @@ def test_solver():
     try:
         test_driver.get('https://www.google.com/recaptcha/api2/demo')
 
-        element = ('xpath', '//iframe[@title="reCAPTCHA"]')
-
-        WebDriverWait(test_driver, 5).until(ec.visibility_of_element_located(element))
-
-        recaptcha_iframe = test_driver.find_element(*element)
+        recaptcha_iframe = test_driver.find_element(By.XPATH, '//iframe[@title="reCAPTCHA"]')
 
         solver.click_recaptcha_v2(iframe=recaptcha_iframe)
 
